Stan Math Library: stan/math/fwd/scal/fun/grad_inc_beta.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
grad_inc_beta.hpp File Reference
`#include <stan/math/fwd/scal/fun/fabs.hpp>`
`#include <stan/math/fwd/scal/fun/log.hpp>`
`#include <stan/math/fwd/scal/fun/log1m.hpp>`
`#include <stan/math/fwd/scal/fun/lbeta.hpp>`
`#include <stan/math/fwd/scal/fun/exp.hpp>`
`#include <stan/math/fwd/scal/fun/value_of.hpp>`
`#include <stan/math/prim/scal/fun/value_of.hpp>`
`#include <stan/math/fwd/core.hpp>`
`#include <stan/math/fwd/scal/fun/inc_beta.hpp>`
`#include <stan/math/prim/scal/fun/grad_2F1.hpp>`
`#include <cmath>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
void | stan::math::grad_inc_beta (stan::math::fvar< T > &g1, stan::math::fvar< T > &g2, stan::math::fvar< T > a, stan::math::fvar< T > b, stan::math::fvar< T > z)

[ Stan Home Page ] © 2011–2016, Stan Development Team.